==> haskell-th-utilities-0.2.5.2-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-EpYE5HcyrQFyIuUIuiExK
key:                  th-utilities-0.2.5.2-EpYE5HcyrQFyIuUIuiExK
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  f55113562ca2f7fe9245b6454386a3d0
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-EpYE5HcyrQFyIuUIuiExK
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.9.1.0-Jxt7FQpUmq1Ffbc4VwJGN5
    syb-0.7.3-DvMMPSfjQylGDaZxljQ4qT template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.16-BZRXGZj12P05b4jzt6nEkR

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.2-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-CfPPyPa9Wr4u3e5kI0EZh
key:                  th-utilities-0.2.5.2-CfPPyPa9Wr4u3e5kI0EZh
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  c23c1fb7e1e9ca21ab396c6d2982931c
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-CfPPyPa9Wr4u3e5kI0EZh
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.16-BbjUDH2XITQv3KGWQe7LC

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
